summaryrefslogtreecommitdiffhomepage
path: root/dev/ZKA/KernelKit
diff options
context:
space:
mode:
authorAmlal El Mahrouss <amlal.elmahrouss@icloud.com>2024-09-04 17:29:07 +0200
committerAmlal El Mahrouss <amlal.elmahrouss@icloud.com>2024-09-04 17:29:07 +0200
commit8b1114ea205ef6560fb7bf5713577d1ab7deb5be (patch)
tree88dc9dc3c6af1d51db46a11dbb0dd9de09409250 /dev/ZKA/KernelKit
parenta0a90c80e5dd17df8f609aebc253b4bf9147f90f (diff)
[ MR ] BUMP commit.
Signed-off-by: Amlal El Mahrouss <amlal.elmahrouss@icloud.com>
Diffstat (limited to 'dev/ZKA/KernelKit')
-rw-r--r--dev/ZKA/KernelKit/CodeMgr.hxx (renamed from dev/ZKA/KernelKit/CodeManager.hxx)8
-rw-r--r--dev/ZKA/KernelKit/DLLInterface.hxx11
-rw-r--r--dev/ZKA/KernelKit/DebugOutput.hxx2
-rw-r--r--dev/ZKA/KernelKit/DeviceMgr.hxx (renamed from dev/ZKA/KernelKit/DeviceManager.hxx)6
-rw-r--r--dev/ZKA/KernelKit/DriveMgr.hxx (renamed from dev/ZKA/KernelKit/DriveManager.hxx)4
-rw-r--r--dev/ZKA/KernelKit/FileMgr.hxx (renamed from dev/ZKA/KernelKit/FileManager.hxx)30
-rw-r--r--dev/ZKA/KernelKit/MP.hxx2
-rw-r--r--dev/ZKA/KernelKit/PCI/Dma.hxx2
-rw-r--r--dev/ZKA/KernelKit/PECodeMgr.hxx (renamed from dev/ZKA/KernelKit/PECodeManager.hxx)4
-rw-r--r--dev/ZKA/KernelKit/PEFCodeMgr.hxx (renamed from dev/ZKA/KernelKit/PEFCodeManager.hxx)4
-rw-r--r--dev/ZKA/KernelKit/PEFDLLInterface.hxx4
-rw-r--r--dev/ZKA/KernelKit/UserProcessScheduler.hxx5
12 files changed, 46 insertions, 36 deletions
diff --git a/dev/ZKA/KernelKit/CodeManager.hxx b/dev/ZKA/KernelKit/CodeMgr.hxx
index ef9d18f4..8c4f090f 100644
--- a/dev/ZKA/KernelKit/CodeManager.hxx
+++ b/dev/ZKA/KernelKit/CodeMgr.hxx
@@ -2,8 +2,8 @@
Copyright ZKA Technologies.
- File: CodeManager.hpp
- Purpose: Code Manager and Shared Objects.
+ File: CodeMgr.hpp
+ Purpose: Code Mgr and Shared Objects.
Revision History:
@@ -14,8 +14,8 @@
#pragma once
-#include <KernelKit/PECodeManager.hxx>
-#include <KernelKit/PEFCodeManager.hxx>
+#include <KernelKit/PECodeMgr.hxx>
+#include <KernelKit/PEFCodeMgr.hxx>
#include <KernelKit/PEFDLLInterface.hxx>
namespace Kernel
diff --git a/dev/ZKA/KernelKit/DLLInterface.hxx b/dev/ZKA/KernelKit/DLLInterface.hxx
index 370363b7..13f36b82 100644
--- a/dev/ZKA/KernelKit/DLLInterface.hxx
+++ b/dev/ZKA/KernelKit/DLLInterface.hxx
@@ -35,8 +35,15 @@ namespace Kernel
virtual DLL_TRAITS** GetAddressOf() = 0;
virtual DLL_TRAITS* Get() = 0;
- virtual void Mount(DLL_TRAITS* to_mount) = 0;
- virtual void Unmount() = 0;
+ virtual Void Mount(DLL_TRAITS* to_mount) = 0;
+ virtual Void Unmount() = 0;
+
+
+ template <typename SymbolType>
+ SymbolType Load(const Char* symbol_name, SizeT len, Int32 kind)
+ {
+ return nullptr;
+ }
};
/// @brief Pure implementation, missing method/function handler.
diff --git a/dev/ZKA/KernelKit/DebugOutput.hxx b/dev/ZKA/KernelKit/DebugOutput.hxx
index fcf18bff..66105aa1 100644
--- a/dev/ZKA/KernelKit/DebugOutput.hxx
+++ b/dev/ZKA/KernelKit/DebugOutput.hxx
@@ -6,7 +6,7 @@
#pragma once
-#include <KernelKit/DeviceManager.hxx>
+#include <KernelKit/DeviceMgr.hxx>
#include <CompilerKit/CompilerKit.hxx>
#include <NewKit/OwnPtr.hxx>
#include <NewKit/Stream.hxx>
diff --git a/dev/ZKA/KernelKit/DeviceManager.hxx b/dev/ZKA/KernelKit/DeviceMgr.hxx
index 5164ae28..473af601 100644
--- a/dev/ZKA/KernelKit/DeviceManager.hxx
+++ b/dev/ZKA/KernelKit/DeviceMgr.hxx
@@ -14,13 +14,15 @@
#pragma once
-/* Kernel device interface manager. */
-/* @file KernelKit/DeviceManager.hpp */
+/* Device manager. */
+/* @file KernelKit/DeviceMgr.hpp */
/* @brief Device abstraction and I/O buffer. */
#include <NewKit/ErrorOr.hxx>
#include <NewKit/Ref.hxx>
+#define cDevicePath "\\Mount\\"
+
// Last Rev
// Wed, Apr 3, 2024 9:09:41 AM
diff --git a/dev/ZKA/KernelKit/DriveManager.hxx b/dev/ZKA/KernelKit/DriveMgr.hxx
index 96fbd95d..4b2cdc73 100644
--- a/dev/ZKA/KernelKit/DriveManager.hxx
+++ b/dev/ZKA/KernelKit/DriveMgr.hxx
@@ -10,12 +10,12 @@
#include <KernelKit/UserProcessScheduler.hxx>
#include <CompilerKit/CompilerKit.hxx>
#include <KernelKit/DebugOutput.hxx>
-#include <KernelKit/DeviceManager.hxx>
+#include <KernelKit/DeviceMgr.hxx>
#include <KernelKit/LPC.hxx>
#include <NewKit/Defines.hxx>
#include <NewKit/String.hxx>
-#define kDriveManagerCount (4U)
+#define kDriveMgrCount (4U)
#define kDriveInvalidID (-1)
#define kDriveNameLen (32)
diff --git a/dev/ZKA/KernelKit/MP.hxx b/dev/ZKA/KernelKit/MP.hxx
index 51f3472a..cf5d6754 100644
--- a/dev/ZKA/KernelKit/MP.hxx
+++ b/dev/ZKA/KernelKit/MP.hxx
@@ -103,7 +103,7 @@ namespace Kernel
operator bool() noexcept;
public:
- /// @brief Shared instance of the MP Manager.
+ /// @brief Shared instance of the MP Mgr.
/// @return the reference to the mp manager class.
STATIC HardwareThreadScheduler& The();
diff --git a/dev/ZKA/KernelKit/PCI/Dma.hxx b/dev/ZKA/KernelKit/PCI/Dma.hxx
index 43df13f0..8e51bc45 100644
--- a/dev/ZKA/KernelKit/PCI/Dma.hxx
+++ b/dev/ZKA/KernelKit/PCI/Dma.hxx
@@ -6,7 +6,7 @@
#pragma once
-#include <KernelKit/DeviceManager.hxx>
+#include <KernelKit/DeviceMgr.hxx>
#include <KernelKit/PCI/Device.hxx>
#include <NewKit/Array.hxx>
#include <NewKit/OwnPtr.hxx>
diff --git a/dev/ZKA/KernelKit/PECodeManager.hxx b/dev/ZKA/KernelKit/PECodeMgr.hxx
index f42c7c21..7b84fbc1 100644
--- a/dev/ZKA/KernelKit/PECodeManager.hxx
+++ b/dev/ZKA/KernelKit/PECodeMgr.hxx
@@ -2,8 +2,8 @@
Copyright ZKA Technologies.
- File: PECodeManager.hxx
- Purpose: PE32+ Code Manager and Shared Objects.
+ File: PECodeMgr.hxx
+ Purpose: PE32+ Code Mgr and Shared Objects.
Revision History:
diff --git a/dev/ZKA/KernelKit/PEFCodeManager.hxx b/dev/ZKA/KernelKit/PEFCodeMgr.hxx
index dd6daca5..74cc8eb0 100644
--- a/dev/ZKA/KernelKit/PEFCodeManager.hxx
+++ b/dev/ZKA/KernelKit/PEFCodeMgr.hxx
@@ -10,7 +10,7 @@
#include <KernelKit/PEF.hxx>
#include <NewKit/ErrorOr.hxx>
#include <NewKit/String.hxx>
-#include <KernelKit/FileManager.hxx>
+#include <KernelKit/FileMgr.hxx>
#define kPefApplicationMime "application/x-newos-exec"
@@ -47,7 +47,7 @@ namespace Kernel
private:
#ifdef __FSKIT_USE_NEWFS__
- OwnPtr<FileStream<Char, NewFilesystemManager>> fFile;
+ OwnPtr<FileStream<Char, NewFilesystemMgr>> fFile;
#else
OwnPtr<FileStream<Char>> fFile;
#endif // __FSKIT_USE_NEWFS__
diff --git a/dev/ZKA/KernelKit/PEFDLLInterface.hxx b/dev/ZKA/KernelKit/PEFDLLInterface.hxx
index ef1a844f..d664bfd8 100644
--- a/dev/ZKA/KernelKit/PEFDLLInterface.hxx
+++ b/dev/ZKA/KernelKit/PEFDLLInterface.hxx
@@ -11,7 +11,7 @@
#define __KERNELKIT_SHARED_OBJECT_HXX__
#include <KernelKit/PEF.hxx>
-#include <KernelKit/PEFCodeManager.hxx>
+#include <KernelKit/PEFCodeMgr.hxx>
#include <NewKit/Defines.hxx>
#include <KernelKit/DLLInterface.hxx>
@@ -96,7 +96,7 @@ namespace Kernel
PEFLoader* fLoader{nullptr};
};
- typedef PEFDLLInterface* DLLInterfacePtr;
+ typedef DLLInterface* DLLInterfacePtr;
EXTERN_C DLLInterfacePtr rtl_init_shared_object(UserProcess* header);
EXTERN_C Void rtl_fini_shared_object(UserProcess* header, DLLInterfacePtr lib, Bool* successful);
diff --git a/dev/ZKA/KernelKit/UserProcessScheduler.hxx b/dev/ZKA/KernelKit/UserProcessScheduler.hxx
index 809dbb7f..78d75af6 100644
--- a/dev/ZKA/KernelKit/UserProcessScheduler.hxx
+++ b/dev/ZKA/KernelKit/UserProcessScheduler.hxx
@@ -10,6 +10,7 @@
#include <ArchKit/ArchKit.hxx>
#include <KernelKit/LockDelegate.hxx>
#include <KernelKit/User.hxx>
+#include <KernelKit/DLLInterface.hxx>
#include <NewKit/MutableArray.hxx>
#define kSchedMinMicroTime (AffinityKind::kStandard)
@@ -158,13 +159,13 @@ namespace Kernel
SizeT StackSize{mib_cast(8)};
// shared library handle, reserved for kDLLKind types of executables only.
- PEFDLLInterface* DLLPtr{nullptr};
+ DLLInterface* DLLPtr{nullptr};
UserProcess* Parent{nullptr};
// Memory usage.
SizeT UsedMemory{0};
SizeT FreeMemory{0};
- SizeT SizeMemory{gib_cast(4)};
+ SizeT SizeMemory{mib_cast(64)};
enum
{
diff --git a/dev/ZKA/KernelKit/FileManager.hxx b/dev/ZKA/KernelKit/FileMgr.hxx
index 05f74a63..7a97f821 100644
--- a/dev/ZKA/KernelKit/FileManager.hxx
+++ b/dev/ZKA/KernelKit/FileMgr.hxx
@@ -2,7 +2,7 @@
Copyright ZKA Technologies.
- File: FileManager.hxx
+ File: FileMgr.hxx
Purpose: Kernel file manager.
------------------------------------------- */
@@ -71,31 +71,31 @@ namespace Kernel
typedef VoidPtr NodePtr;
/**
- @brief Filesystem Manager Interface class
+ @brief Filesystem Mgr Interface class
@brief Used to provide common I/O for a specific filesystem.
*/
- class FilesystemManagerInterface
+ class FilesystemMgrInterface
{
public:
- explicit FilesystemManagerInterface() = default;
- virtual ~FilesystemManagerInterface() = default;
+ explicit FilesystemMgrInterface() = default;
+ virtual ~FilesystemMgrInterface() = default;
public:
- ZKA_COPY_DEFAULT(FilesystemManagerInterface);
+ ZKA_COPY_DEFAULT(FilesystemMgrInterface);
public:
/// @brief Mounts a new filesystem into an active state.
/// @param interface the filesystem interface
/// @return
- static bool Mount(FilesystemManagerInterface* interface);
+ static bool Mount(FilesystemMgrInterface* interface);
/// @brief Unmounts the active filesystem
/// @return
- static FilesystemManagerInterface* Unmount();
+ static FilesystemMgrInterface* Unmount();
/// @brief Getter, gets the active filesystem.
/// @return
- static FilesystemManagerInterface* GetMounted();
+ static FilesystemMgrInterface* GetMounted();
public:
virtual NodePtr Create(_Input const Char* path) = 0;
@@ -137,17 +137,17 @@ namespace Kernel
#ifdef __FSKIT_USE_NEWFS__
/**
* @brief Based of FilesystemManagerInterface, takes care of managing NewFS
* disks.
*/
- class NewFilesystemManager final : public FilesystemManagerInterface
+ class NewFilesystemMgr final : public FilesystemMgrInterface
{
public:
- explicit NewFilesystemManager();
- ~NewFilesystemManager() override;
+ explicit NewFilesystemMgr();
+ ~NewFilesystemMgr() override;
public:
- ZKA_COPY_DEFAULT(NewFilesystemManager);
+ ZKA_COPY_DEFAULT(NewFilesystemMgr);
public:
NodePtr Create(const Char* path) override;
@@ -192,7 +192,7 @@ namespace Kernel
* @tparam FSClass Filesystem contract who takes care of it.
*/
template <typename Encoding = Char,
- typename FSClass = FilesystemManagerInterface>
+ typename FSClass = FilesystemMgrInterface>
class FileStream final
{
public:
@@ -137,17 +137,17 @@ namespace Kernel
#ifdef __FSKIT_USE_NEWFS__
/**
- * @brief Based of FilesystemManagerInterface, takes care of managing NewFS
+ * @brief Based of FilesystemMgrInterface, takes care of managing NewFS
* disks.
*/